import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:nfc_manager/nfc_manager.dart';
import 'dart:convert';

class NFCService {
  static Future<String?> readNFC(BuildContext context) async {
    try {
      bool isAvailable = await NfcManager.instance.isAvailable();
      if (!isAvailable) {
        ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text("NFC n'est pas disponible sur cet appareil")));
        return null;
      }

      String? nfcData;

      await NfcManager.instance.startSession(
        onDiscovered: (NfcTag tag) async {
          // Essayez de récupérer les données NDEF du tag.
          var ndef = Ndef.from(tag);
          print('ndef : ${ndef}');
          if (ndef != null && ndef.cachedMessage?.records.isNotEmpty == true) {
            // Assurez-vous que le payload n'est pas vide et convertissez-le en String.
            Uint8List? payload = ndef.cachedMessage!.records.first.payload;
            if (payload != null && payload.isNotEmpty) {
              nfcData = utf8.decode(payload.sublist(3));
              NfcManager.instance.stopSession();
            }
          }
        },
      );

      return nfcData;
    } catch (e) {
      NfcManager.instance.stopSession(errorMessage: e.toString());
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text("Erreur lors de la lecture NFC: $e")));
      return null;
    }
  }
}
